@@ -206,7 +206,7 @@ void usage()
    -f               stay in the foreground, don't run as a daemon\n\
    -g x             run as group <x>\n\
    -p x             use pid file <x> instead of the default\n\
-                    '-' means not tu use any pid file\n\
+                    '-' means not to use any pid file\n\
    -u x             run as user <x>\n"
 ));
 }
